Crick
=====

|Build Status| |Conda Badge| |PyPI Badge|

Crick is a fast library of approximate and streaming algorithms. It is still a
work in progress, use at your own risk.

Installation
------------

Crick is available via ``conda`` or ``pip``:

::

   # Install with conda
   $ conda install crick -c conda-forge

   # Install with pip
   $ pip install crick

.. |Build Status| image:: https://github.com/dask/crick/actions/workflows/tests.yml/badge.svg
   :target: https://github.com/dask/crick/actions/workflows/tests.yml
.. |PyPI Badge| image:: https://img.shields.io/pypi/v/crick.svg
   :target: https://pypi.python.org/pypi/crick
.. |Conda Badge| image:: https://anaconda.org/conda-forge/crick/badges/version.svg
   :target: https://anaconda.org/conda-forge/crick
